#-----------------------------------------------------------------------------
# DelProps
# Copyright (c) 2004 David G. Drumright (Ockham)
# May 21, 2004
# Delete the selected items and all their children.
#-----------------------------------------------------------------------------

from Tkinter import *
import poser
scene = poser.Scene()

#-----------------------------------------------------------------------------
Deletables={}  # Dict so we can avoid redundancy
global Deletables
# Recursive.  We could get in trouble by deleting as we go,
# so we add names to a list, then go back and delete everything in the list.
def FindDeletables(Name):
    global Deletables
    ActorArg=scene.Actor(Name)
    Deletables[Name]=1  # Add name to keys, no redund
    if ActorArg.Children():
        for OneChild in ActorArg.Children():
            Name=OneChild.Name()
            FindDeletables(Name)  # Recursive

#-----------------------------------------------------------------------------
# Next section is TK
#------------------------------------------------------------

class App:
    def __init__(self, master, textMessage):
        self.master = master
        master.title("Prop deleter")

        self.Labelbox = Label(self.master,text="Highlight props in list, then hit Delete").grid(row=1, column=0,columnspan=3)

        # Lists
        self.ListScroll = Scrollbar(self.master, orient=VERTICAL)
        self.ListScroll.grid( row=2, column=0,sticky=N+S+E)
        self.List = Listbox(self.master, height=5, selectmode=MULTIPLE,yscrollcommand = self.ListScroll.set)
        self.List.grid( row=2, column=1)
        # Set the scrollbar to work
        self.ListScroll["command"] = self.List.yview
        # Fill list with all PP2 in the scene
        for OneActor in scene.Actors():
            if (OneActor.IsProp()) and ( OneActor.Name() != 'GROUND'):
                Name=OneActor.Name()
                self.List.insert(END,Name)

        # Go/nogo buttons.
        self.buttonGo = Button(self.master, text="Delete", command=self.HandleGo)
        self.buttonGo.grid(row=3, column=0)

        self.buttonCancel = Button(self.master, text="Cancel", command=self.HandleCancel)
        self.buttonCancel.grid(row=3, column=2)

        self.master.protocol('WM_DELETE_WINDOW', self.HandleCancel)


    # - - - - - - - - - - - - - - - - - -

    def Update(self):
        if scene: scene.ProcessSomeEvents(1)
        root.lift()
        root.after(100, self.Update)

    # - - - - - - - - - - - - - - - - - -

    def HandleGo(self):
        # Go through selected items.  For each, find all of its childs and delete them.
        Sels=self.List.curselection()
        if not Sels:  # Do all in list
            for OneIndex in range(self.List.size()):
                ActorName=self.List.get(OneIndex)
                FindDeletables(ActorName)
        else: # Sels
            for OneIndex in Sels:
                ActorName=self.List.get(int(OneIndex))
                FindDeletables(ActorName)
        # Now take the list formed by the recursive FindDeletables, and delete
        # everything in it.
        for OneName in Deletables.keys():
            scene.SelectActor(scene.Actor(OneName))
            scene.DeleteCurrentProp()
            scene.DrawAll()

        self.master.destroy()

    # - - - - - - - - - - - - - - - - - -

    def HandleCancel(self):
        self.master.destroy()

#------------------------------------------------------------
# Activate the loop
#------------------------------------------------------------

root = Tk()
app = App(root, '')
app.Update()
root.mainloop()

#------------------------------------------------------------
# End TK loop.
#-----------------------------------------------------------------------------
